Stan Math Library: stan::math::common_type< T1, T2 > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::common_type< T1, T2 > Struct Template Reference

`#include <common_type.hpp>`

## Public Types
typedef boost::math::tools::promote_args< T1, T2 >::type | type

## Detailed Description

### template<typename T1, typename T2>
struct stan::math::common_type< T1, T2 >

Definition at line 13 of file common_type.hpp.

## Member Typedef Documentation

template<typename T1, typename T2>

typedef boost::math::tools::promote_args<T1, T2>::type stan::math::common_type< T1, T2 >::type

Definition at line 14 of file common_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/fun/common_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.